@@ -1,7 +1,7 @@
 package Module::DataPack;
 
-our $DATE = '2015-06-12'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-06-17'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -314,12 +314,16 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.01 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-06-12.
+This document describes version 0.02 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-06-17.
 
 =head1 SEE ALSO
 
 L<App::FatPack>, L<App::fatten>
 
+L<Data::Section::Seekable>, the format used for the data section
+
+L<datapack-modules>, CLI for C<datapack_modules>.
+
 =head1 FUNCTIONS
 
 
